# Rustic AI Playwright

This module employs [Playwright](https://playwright.dev/python/docs/intro) to facilitate web scraping tasks.

## Installing

```shell
pip install rusticai-playwright
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```
